@@ -19,19 +19,26 @@ from classy_imaginary.modules.midas.utils import AddMiDaS
 from classy_imaginary.safety import create_safety_score, EnhancedStableDiffusionSafetyChecker
 from classy_imaginary.samplers import SAMPLER_LOOKUP
 from classy_imaginary.samplers.base import NoiseSchedule, noise_an_image
-from classy_imaginary.utils import get_device, platform_appropriate_autocast, fix_torch_nn_layer_norm, fix_torch_group_norm, randn_seeded
+from classy_imaginary.utils import get_device, platform_appropriate_autocast, fix_torch_nn_layer_norm, \
+    fix_torch_group_norm, randn_seeded
 import logging
 from transformers import logging as transformers_logging, AutoFeatureExtractor
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 transformers_logging.set_verbosity_error()
+
+
 # logging.disable_default_handler()
 
 
 class Imagine:
-    def __init__(self, model_name: str = "SD-1.5", half_mode: bool = None, precision="autocast",
-                 for_inpainting: bool = False):
+    def __init__(self,
+                 model_name: str = "SD-1.5",
+                 half_mode: bool = None,
+                 precision="autocast",
+                 for_inpainting: bool = False,
+                 nsfw_filter: bool = False):
         """
         Initialize the Imagine class.
         :param model_name: the name of the SD model to use.
@@ -50,10 +57,12 @@ class Imagine:
         )
         self.midas_model = AddMiDaS()
         safety_model_id = "CompVis/stable-diffusion-safety-checker"
-        self.safety_feature_extractor = AutoFeatureExtractor.from_pretrained(safety_model_id)
-        self.safety_checker = EnhancedStableDiffusionSafetyChecker.from_pretrained(
-            safety_model_id
-        )
+        self.nsfw_filter = nsfw_filter
+        if nsfw_filter:
+            self.safety_feature_extractor = AutoFeatureExtractor.from_pretrained(safety_model_id)
+            self.safety_checker = EnhancedStableDiffusionSafetyChecker.from_pretrained(
+                safety_model_id
+            )
 
     def imagine(self,
                 prompt: ImaginePrompt,
@@ -326,15 +335,16 @@ class Imagine:
                     upscaled_img = None
                     rebuilt_orig_img = None
 
-                    with lc.timing("safety-filter"):
-                        safety_score = create_safety_score(
-                            self.safety_checker,
-                            self.safety_feature_extractor,
-                            img,
-                            safety_mode=IMAGINAIRY_SAFETY_MODE
-                        )
+                    if self.nsfw_filter:
+                        with lc.timing("safety-filter"):
+                            safety_score = create_safety_score(
+                                self.safety_checker,
+                                self.safety_feature_extractor,
+                                img,
+                                safety_mode=IMAGINAIRY_SAFETY_MODE
+                            )
 
-                    if not safety_score.is_filtered:
+                    if not self.nsfw_filter or not safety_score.is_filtered:
                         if prompt.fix_faces:
                             logger.info("Fixing 😊 's in 🖼  using CodeFormer...")
                             img = enhance_faces(img, fidelity=prompt.fix_faces_fidelity)
